<?php

declare(strict_types=1);

namespace Dedi\SyliusImportExportPlugin\Controller;

use FriendsOfSylius\SyliusImportExportPlugin\Form\ImportType;
use FriendsOfSylius\SyliusImportExportPlugin\Importer\ImporterRegistry;
use Symfony\Bundle\FrameworkBundle\Controller\AbstractController;
use Symfony\Component\HttpFoundation\Request;
use Symfony\Component\HttpFoundation\Response;
use Symfony\Component\Routing\Exception\ResourceNotFoundException;

class ImportController extends AbstractController
{
    private readonly ImporterRegistry $importerRegistry;

    public function __construct(ImporterRegistry $importerRegistry)
    {
        $this->importerRegistry = $importerRegistry;
    }

    public function renderFormAction(Request $request): Response
    {
        $resource = $request->attributes->get('resource');
        $format = $request->attributes->get('format');
        $defaultAttributes = $request->attributes->get('_sylius');

        $name = ImporterRegistry::buildServiceName($resource, $format);
        if (!$this->importerRegistry->has($name)) {
            throw new ResourceNotFoundException(sprintf('No importer found for resource "%s"', $resource));
        }

        $form = $this->createForm(
            $defaultAttributes['form'] ?? ImportType::class,
            null,
            ['importer_type' => $resource]
        );

        $template = $defaultAttributes['template'] ?? '@DediSyliusImportExportPlugin/Admin/Import/index.html.twig';

        return $this->render($template, [
            'form' => $form->createView(),
            'resource' => $resource,
        ]);
    }
}
